=======
Harriet
=======

- version number: 0.1.0
- author: Kit La Touche

Overview
--------

Integrate DRF and Channels-based websockets.

Installation / Usage
--------------------

To install use pip::

    $ pip install harriet


Or clone the repo::

    $ git clone https://github.com/wlonk/harriet.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD
